import { Component } from '@angular/core';
import { ModalDismissReasons, NgbModal } from '@ng-bootstrap/ng-bootstrap';

function getDismissReason(reason: any): string {
	switch (reason) {
		case ModalDismissReasons.ESC:
			return 'by pressing ESC';
		case ModalDismissReasons.BACKDROP_CLICK:
			return 'by clicking on a backdrop';
		default:
			return `with: ${reason}`;
	}
}

@Component({
	selector: 'modal-component',
	standalone: true,
	template: `
		<ng-template #content let-modal>
			<div class="modal-header">
				<h4 class="modal-title" id="modal-basic-title">Modal</h4>
				<button type="button" class="btn-close" aria-label="Close" (click)="modal.dismiss('Cross click')"></button>
			</div>
			<div class="modal-body">Hello from modal</div>
			<div class="modal-footer">
				<button type="button" class="btn btn-outline-secondary" (click)="modal.close('Save click')">Save</button>
			</div>
		</ng-template>

		<button class="btn btn-outline-primary" (click)="open(content)">Open modal</button>

		<pre>{{ closeResult }}</pre>
	`,
})
export class ModalComponent {
	closeResult: string;

	constructor(private modalService: NgbModal) {}

	open(content) {
		this.modalService.open(content, { ariaLabelledBy: 'modal-basic-title' }).result.then(
			(result) => {
				this.closeResult = `Closed with: ${result}`;
			},
			(reason) => {
				this.closeResult = `Dismissed ${getDismissReason(reason)}`;
			},
		);
	}
}
